@@ -22,38 +22,38 @@
 
 from six import iterbytes
 
-class AtomCacheReference:
+class AtomCacheReference(object):
 	def __init__(self, index):
 		self.index = index
 	def __eq__(self,other):
 		return self.index == other.index
 
-class Reference:
-	def __init__(self, node, id, creation):
+class Reference(object):
+	def __init__(self, node, id_, creation):
 		self.node = node
-		self.id = id
+		self.id = id_
 		self.creation = creation
 	def __eq__(self,other):
 		return self.node == other.node and self.id == other.id and self.creation == other.creation
 
-class Port:
-	def __init__(self, node, id, creation):
+class Port(object):
+	def __init__(self, node, id_, creation):
 		self.node = node
-		self.id = id
+		self.id = id_
 		self.creation = creation
 	def __eq__(self,other):
 		return self.node == other.node and self.id == other.id and self.creation == other.creation
 
-class Pid:
-	def __init__(self, node, id, serial, creation):
+class Pid(object):
+	def __init__(self, node, id_, serial, creation):
 		self.node = node
-		self.id = id
+		self.id = id_
 		self.serial = serial
 		self.creation = creation
 	def __eq__(self,other):
 		return self.node == other.node and self.id == other.id and self.creation == other.creation and self.serial == other.serial
 
-class String:
+class String(object):
 	def __init__(self, value):
 		self.value = value
 	def __eq__(self, other):
@@ -63,26 +63,33 @@ class String:
 	def __len__(self):
 		return len(self.value)
 
-class Binary:
+class Binary(object):
 	def __init__(self, value):
 		self.value = value
 	def __eq__(self, other):
 		return self.value == other.value
 
-class Fun:
+class Fun(object):
 	def __init__(self, arity, uniq, index, module, oldindex, olduniq, pid, free):
 		self.arity = arity
 		self.uniq = uniq
 		self.index = index
 		self.module = module
 		self.oldindex = oldindex
-		self.olduniq = uniq
+		self.olduniq = olduniq
 		self.pid = pid
 		self.free = free
 	def __eq__(self, other):
-		return self.arity == other.arity and self.uniq == other.uniq and self.index == other.index and self.module == other.module and self.oldindex == other.oldindex and self.olduniq == other.uniq and self.pid == other.pid and self.free == other.free
+		return (self.arity == other.arity
+			and self.uniq == other.uniq
+			and self.index == other.index
+			and self.module == other.module
+			and self.oldindex == other.oldindex
+			and self.olduniq == other.olduniq
+			and self.pid == other.pid
+			and self.free == other.free)
 
-class MFA:
+class MFA(object):
 	def __init__(self, module, function, arity):
 		self.module = module
 		self.function = function
@@ -90,7 +97,7 @@ class MFA:
 	def __eq__(self, other):
 		return self.module == other.module and self.function == other.function and self.arity == other.arity
 
-class BitBinary:
+class BitBinary(object):
 	def __init__(self, value, bits):
 		self.value = value
 		self.bits = bits
